pub enum CompareOperator {
Equal,
NotEqual,
Less,
LessOrEqual,
Greater,
GreaterOrEqual,
}Expand description
Ordered comparison operator for one resolved field.
Variants
Equal
Exact type-and-value equality.
NotEqual
Exact inequality; missing still evaluates false.
Less
Less than, only between the same value variants.
LessOrEqual
Less than or equal, only between the same value variants.
Greater
Greater than, only between the same value variants.
GreaterOrEqual
Greater than or equal, only between the same value variants.