ExecutionLimits

Struct ExecutionLimits 

pub struct ExecutionLimits {
    pub max_scanned_records: u64,
    pub max_matched_records: u64,
    pub max_returned_records: usize,
    pub max_groups: usize,
    pub max_filter_nodes: usize,
    pub max_filter_depth: usize,
    pub max_sort_fields: usize,
    pub max_group_fields: usize,
    pub max_metrics: usize,
    pub timeout: Duration,
}
Runtime and shape budgets for one complete global execution.

Fields

max_scanned_records: u64

Maximum records inspected across all shards.

max_matched_records: u64

Maximum records retained after filtering.

max_returned_records: usize

Maximum requested page size.

max_groups: usize

Maximum distinct aggregation groups.

max_filter_nodes: usize

Maximum nodes in the recursive filter expression.

max_filter_depth: usize

Maximum recursive filter depth, counting the root as one.

max_sort_fields: usize

Maximum explicit sort fields.

max_group_fields: usize

Maximum group-key fields.

max_metrics: usize

Maximum metrics in one plan.

timeout: Duration

Cooperative monotonic execution timeout.