pub enum QueryError {
Show 23 variants
EmptyRecordKey,
DuplicateRecordKey,
ZeroLimit,
ResultLimitExceeded {
requested: usize,
maximum: usize,
},
FilterNodesExceeded {
actual: usize,
maximum: usize,
},
FilterDepthExceeded {
actual: usize,
maximum: usize,
},
SortFieldsExceeded {
actual: usize,
maximum: usize,
},
CursorShape {
actual: usize,
expected: usize,
},
EmptyCursorKey,
NoncanonicalCursorNull,
InvalidPrefixType,
InvalidFieldPath,
GroupFieldsExceeded {
actual: usize,
maximum: usize,
},
MetricsExceeded {
actual: usize,
maximum: usize,
},
EmptyMetricName,
DuplicateMetricName {
name: String,
},
ScannedBudgetExceeded {
maximum: u64,
},
MatchedBudgetExceeded {
maximum: u64,
},
GroupBudgetExceeded {
maximum: usize,
},
TimedOut,
MetricTypeMismatch {
name: String,
},
ArithmeticOverflow {
name: String,
},
MetricStateMismatch,
}Expand description
Failure to validate or completely execute one structured query.
Variants
EmptyRecordKey
Record keys must be nonempty.
DuplicateRecordKey
Keys must be globally unique across shards.
ZeroLimit
A page must request at least one row.
ResultLimitExceeded
Requested page size exceeds policy.
FilterNodesExceeded
Filter expression is too large.
FilterDepthExceeded
Filter recursion is too deep.
Fields
SortFieldsExceeded
Too many explicit sort fields were requested.
CursorShape
Cursor shape does not match the sort plan.
EmptyCursorKey
Cursor keys must be nonempty.
NoncanonicalCursorNull
Explicit null must use the canonical None cursor representation.
InvalidPrefixType
A prefix filter literal is not a string or bytes value.
InvalidFieldPath
Field-path segments must be nonempty UTF-8 strings.
GroupFieldsExceeded
Too many group fields were requested.
MetricsExceeded
Too many metrics were requested.
EmptyMetricName
Metric names must be nonempty.
DuplicateMetricName
Metric names must be unique within a plan.
ScannedBudgetExceeded
Global scan budget was exhausted.
MatchedBudgetExceeded
Filtered-result memory budget was exhausted.
GroupBudgetExceeded
Aggregation group budget was exhausted.
TimedOut
Cooperative monotonic deadline expired.
MetricTypeMismatch
Sum encountered a non-integer value.
ArithmeticOverflow
Checked aggregate arithmetic overflowed.
MetricStateMismatch
Internal aggregate state did not match its validated metric plan.